@@ -11,6 +11,7 @@
 # Copyright 2017 Simon <spam@esemi.ru>                                         #
 # Copyright 2018 namc <namratachaudhary@users.noreply.github.com>              #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2018 itsbruce <it.is.bruce@gmail.com>                              #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -65,6 +66,7 @@ class NamedUser(Framework.TestCase):
         self.assertEqual(self.user.private_gists, None)
         self.assertEqual(self.user.public_gists, 16)
         self.assertEqual(self.user.public_repos, 61)
+        self.assertEqual(self.user.suspended_at, None)
         self.assertEqual(self.user.total_private_repos, None)
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/nvie")
@@ -98,6 +100,7 @@ class NamedUser(Framework.TestCase):
         self.assertEqual(self.user.private_gists, 5)
         self.assertEqual(self.user.public_gists, 2)
         self.assertEqual(self.user.public_repos, 11)
+        self.assertEqual(self.user.suspended_at, datetime.datetime(2013, 8, 10, 7, 11, 7))
         self.assertEqual(self.user.total_private_repos, 5)
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/jacquev6")
@@ -107,6 +110,7 @@ class NamedUser(Framework.TestCase):
 
     def testGetGists(self):
         self.assertListKeyEqual(self.user.get_gists(), lambda g: g.description, ["Gist created by PyGithub", "FairThreadPoolPool.cpp", "How to error 500 Github API v3, as requested by Rick (GitHub Staff)", "Cadfael: order of episodes in French DVD edition"])
+        self.assertListKeyEqual(self.user.get_gists(since=datetime.datetime(2012, 3, 1, 17, 0, 0)), lambda g: g.description, ["Gist created by PyGithub", "FairThreadPoolPool.cpp"])
 
     def testGetFollowers(self):
         self.assertListKeyEqual(self.user.get_followers(), lambda f: f.login, ["jnorthrup", "brugidou", "regisb", "walidk", "afzalkhan", "sdanzan", "vineus", "gturri", "fjardon", "cjuniet", "jardon-u", "kamaradclimber", "L42y"])
